body {
    padding-top: 60px;
    padding-bottom: 40px;
}

.anchor {
    position: relative;
    top: -60px;
}

.sidebar-nav {
    padding: 9px 0;
}

footer {
	text-align: center;
}

.dashboard-module {
    padding: 10px;

    h2 {
	font-size: 20px;
	line-height: 20px;
    }
    
    h3 {
	font-size: 15px;
	line-height: 15px;
    }
    
    ul {
	list-style-type: none;
    }
    
    .dashboard-module-content {
    }
}

#dashboard-panel {
	position: relative;

	ul {
		list-style-type: none;
		position: absolute;
		right: 0;
	}
}

a:hover {
    text-decoration: none;
}

th a {
    color: inherit;
}
