{% load intranet_extra i18n %}
{% load url from future %}

<div class="navbar navbar-fixed-top">
  <div class="navbar-inner">
    <div class="container-fluid">
      <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </a>
      <a class="brand" href="{% url 'dashboard' %}">{% intranet_title %}</a>
      <div class="nav-collapse">
        <ul class="nav">
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-user icon-white"></i>&nbsp;{% trans "Profile" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#">
	      <i class="icon-th-list icon-white"></i>&nbsp;{% trans "Entrepreneurs" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#">
	      <i class="icon-th-list icon-white"></i>&nbsp;{% trans "Enterprises" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-file icon-white"></i>&nbsp;{% trans "Documents" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-calendar icon-white"></i>&nbsp;{% trans "Agenda" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-envelope icon-white"></i>&nbsp;{% trans "Messages" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-comment icon-white"></i>&nbsp;{% trans "News" %}</a></li>
	  <li class="divider-vertical"></li>
          <li><a href="#"><i class="icon-question-sign icon-white"></i>&nbsp;{% trans "Forum" %}</a></li>
	  <li class="divider-vertical"></li>
	</ul>
	{% if request.user.is_authenticated %}
	<p class="navbar-text pull-right"><a href="{% url 'logout' %}">{% trans "Logout" %}</a></p>
	<ul class="nav pull-right"><li class="divider-vertical"></li></ul>
	<p class="navbar-text pull-right">{% trans "Logged in as" %}&nbsp;<a href="#">{{ request.user.username }}</a></p>
	{% endif %}
      </div><!--/.nav-collapse -->
    </div>
  </div>
</div>
