{% extends "intranet/index.html" %}
{% load i18n %}

{% block content %}
<div class="span4">&nbsp;</div>
<div class="span4" {% if not form.non_field_errors %}style="margin-top: 70px;"{% endif %}>

  <form action="{% url password-change %}" method="post" class="form-horizontal">
    {% csrf_token %}
    {{ form }}
    <div class="form-actions">
      <a href="{{ cancel_url }}" class="btn">{% trans "Cancel" %}</a>
      <button type="submit" class="btn btn-primary">{% trans "Save Password" %}</button>
    </div>
  </form>

</div>
<div class="span4">&nbsp;</div>

{% endblock %}
