{% extends 'intranet/index-2.html' %}
{% load i18n %}
{% load url from future %}

{% block title_content %}
{% if object %}Edition of {{ object }}{% else %}{% trans "Creation of" %} {{ verbose_name }}{% endif %}
{% endblock %}

{% block content %}
<div class="span2">&nbsp;</div>
<div class="span8">
  <form action="{{ request.path_info }}" method="post" class="form-horizontal" enctype="multipart/form-data">
    {% csrf_token %}
    {{ form }}
    {% block extra_form %}
        {# Here you can add extra fields which are not given by your model, for example hidden fields. #}
    {% endblock %}
    <div class="form-actions">
      {% block form_actions %}
      <a href="{% if object %}{% url urls.cancel object.pk %}{% else %}{% url urls.cancel %}{% endif %}" onclick="history.go(-1); return false;" class="btn">{% trans "Cancel" %}</a>
      <button type="submit" class="btn btn-primary">{% if object %}{% trans "Save" %}{% else %}{% trans "Create" %}{% endif %}</button>
      {% endblock %}
      {% block extra_form_actions %}{% endblock %}
    </div>
  </form>
</div>
{% endblock %}
