{% load static from staticfiles %}
{% load intranet_extra %}

<!DOCTYPE html>
<html lang="fr">
  <head>
    <meta charset="utf-8">
    <title>{% block title_page %}{% title %}{% endblock %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="{{ description }}">
    <meta name="author" content="{{ author }}">
    {# jQuery #}
    <script type="text/javascript" src="{% static "js/jquery-1.7.2.min.js" %}"></script>
    {# jQuery UI #}
    <script type="text/javascript" src="{% static "js/jquery-ui-1.8.17.custom.min.js" %}"></script>
    <script type="text/javascript" src="{% static "js/jquery-ui-timepicker-addon.js" %}"></script>
    <link rel="stylesheet" type="text/css" href="{% static "css/smoothness/jquery-ui-1.8.17.custom.css" %}">
    {# CSRF Protection #}
    <script type="text/javascript" src="{% static "intranet/js/csrf.js" %}"></script>

    {% block css %}
    <link rel="stylesheet" type="text/css" href="{% static "intranet/bootstrap/css/bootstrap.min.css" %}">
    <link rel="stylesheet/less" type="text/css" href="{% static "intranet/css/intranet.less" %}">
    {% block css_extra %}{% endblock %}
    <script src="{% static "js/less-1.3.0.min.js" %}" type="text/javascript"></script>
    {% comment %}
    <link href="{% static "intranet/bootstrap/css/bootstrap-responsive.min.css" %}" rel="stylesheet">
    {% endcomment %}
    {% endblock css %}


    <!-- Le HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    <link rel="shortcut icon" href="{% static 'favicon.ico' %}">
  </head>

  <body>
    {% include 'intranet/navbar.html' %}

    <div class="container-fluid">

      <div class="row-fluid">

	{% block wrap_content %}{% endblock %}
    
      </div><!--/row-->
  
      {% include 'intranet/footer.html' %}

    </div> <!-- /container -->

    {% block js %}
    <script type="text/javascript" src="{% static "intranet/bootstrap/js/bootstrap.min.js" %}"></script>
    {% block js_extra %}{% endblock %}
    {% endblock js %}
  </body>
</html>
