{% extends 'intranet/base.html' %}

{% block wrap_content %}

<div class="span2">

  {% block wrap_sidebar %}
  <div id="sidebar" class="well sidebar-nav">
    <ul class="nav nav-list">

      {% block sidebar %}
      {% endblock sidebar %}

    </ul>
  </div><!--/.well -->
  {% endblock wrap_sidebar %}

</div><!--/span-->
<div class="span10">

  <div class="row-fluid">
    
    {% block wrap_title_content %}
    <div class="page-header">
      <h1>{% block title_content %}{% endblock %}
	<span class="pull-right actions-content-list">{% block actions_content %}{% endblock %}</span></h1>
    </div>
    {% endblock %}
    {% block content %}{% endblock %}
  </div>

</div><!--/span-->
  
{% endblock %}
