{% extends 'intranet/index-2.html' %}
{% load i18n intranet_extra %}
{% load url from future %}


{% block sidebar %}
<li class="nav-header">{{ verbose_name_plural|capfirst }}</li>
{% for item in object_list %}
<li{% if item == object %} class="active"{% endif %}><a href="{% url urls.detail item.pk %}">{{ item }}</a></li>
{% endfor %}
{% endblock sidebar %}

{% block title_content %}{{ verbose_name|capfirst }} : {{ object }}{% endblock %}

{% block actions_content %}

{% block default_go_back_list_action %}
<a class="btn btn-primary" href="{% url urls.list %}">{% trans "Go back to list" %}</a>
{% endblock %}

{% block default_update_action %}
{% has_perm prefix='change' obj=object as change_perm %}
{% if change_perm %}
<a class="btn btn-primary" href="{% url urls.edit object.pk %}">{% trans "Edit" %}</a>
{% endif %}
{% endblock %}

{% block default_delete_action %}
{% has_perm prefix='delete' obj=object as delete_perm %}
{% if delete_perm %}
<a class="btn btn-danger" href="{% url urls.delete object.pk %}">{% trans "Delete" %}</a>
{% endif %}
{% endblock %}
{% block extra_actions_content %}{% endblock %}

{% endblock %}
