{% extends 'intranet/index-2.html' %}
{% load i18n %}
{% load url from future %}

{% block title_content %}
{% trans "Deletion of" %} {{ verbose_name|capfirst }} : {{ object }}
{% endblock %}

{% block content %}
<div class="span2">&nbsp;</div>
<div class="span10">
  <form action="{{ request.path_info }}" method="post" class="form-horizontal">
    {% csrf_token %}
    <h3>{% trans "Are you sure to want delete this item ?" %}</h3>
    <div class="form-actions">
      {% block delete_form_actions %}
      <a href="{% url urls.cancel object.pk %}" class="btn">{% trans "Cancel" %}</a>
      <button type="submit" class="btn btn-danger">{% trans "Delete" %}</button>
      {% endblock %}
    </div>
  </form>
</div>
{% endblock %}
