{% extends 'intranet/index.html' %}
{% load admin_tools_dashboard_tags i18n %}

{% block title %}{% trans "Dashboard" %} - {{ request.user.get_profile.verbose_status }} - {{ block.super }}{% endblock %}
{% block css_extra %}
{% admin_tools_render_dashboard_css %}
{% endblock %}

{% block content %}

<div class="row-fluid">

  {% admin_tools_render_dashboard "index" request.user.get_profile.dashboard %}

</div>
{% endblock %}
