{% extends "intranet/index.html" %}
{% load i18n %}

{% block content %}
<div class="span4">&nbsp;</div>
<div class="span4" {% if not form.non_field_errors %}style="margin-top: 70px;"{% endif %}>

  <form action="{% url login %}" method="post" class="form-horizontal">
    {% csrf_token %}
    {{ form }}
    <div class="form-actions">
      <button type="submit" class="btn btn-primary">{% trans "Login" %}</button>
    </div>
    <input type="hidden" name="next" value="{{ next }}" />
  </form>

</div>
<div class="span4">&nbsp;</div>
<script type="text/javascript">
  window.onload = function() {
      document.getElementById("id_username").focus();
  };
</script>
{% endblock %}
